      SUBROUTINE LPGEOM
*.
*...LPGEOM   Define GEANT geometries for the large prototype detector
*.
*. SEQUENCE  : GCCUTS GCONST GCFLAG GCLIST
*.           : GMMATM LPCGEO RCREP  XECGEO XECPMT
*. CALLS     : GGCLOS GMMATE GMTMED GSATT  GSPOS  GSPOSP GSROTM GSVOLU
*.           : USGEOM XEGINI XEGPMT
*. CALLED    : UGINIT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.03
*. CREATED   : 06-May-00
*. LAST MOD  : 06-Sep-01
*.
*. Modification Log.
*. 06-Sep-01   W.Ootani        (V1.03) Take account of liquid xenon
*.                             surface
*. 22-May-00   T.Mashimo       (V1.02) LPTMED,'LQXE' -> GMTMED,'XELQ'.
*. 16-May-00   T.Mashimo       (V1.01) SPxxxx->VPxxxx.  GMTMED->LPTMED.
*.                             Geant initial volume now 'LP  ' instead
*.                             of 'MEG '.
*. 06-May-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcflag.inc"
#include "geant321/gclist.inc"
#include "rcrep.inc"
#include "gmmatm.inc"
#include "lpcgeo.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
*
      LOGICAL INIT
      SAVE    INIT
      INTEGER IUCOMP
      EXTERNAL IUCOMP
*
      REAL    VPXEVA(3), VPXELQ(3)
      REAL    VPXPH1(3), VPXPH2(3), VPXPH3(3)
      REAL    VPXPHL(3,3)
      EQUIVALENCE (VPXPH1(1), VPXPHL(1,1))
      EQUIVALENCE (VPXPH2(1), VPXPHL(1,2))
      EQUIVALENCE (VPXPH3(1), VPXPHL(1,3))
      REAL    VPXEHP(3), VPXEHC(3), VPXEAW(3)
      INTEGER IVOL
*
      INTEGER IW, IX, IY, I, IPMT
      INTEGER IROT,   IROTAR(6)
      REAL    XPOS0,  YPOS0,  ZPOS0
      REAL    XPOSWD, YPOSWD, ZPOSWD,
     +        XPOSPM, YPOSPM, ZPOSPM,
     +        XPOSHL(3), YPOSHL(3), ZPOSHL(3)
      REAL    ZMXELQ, ZCXELQ, ZMXEVA, ZCXEVA
      REAL    ZPXEHP(2), ZPXEHC, ZPXEAW
*
      DATA INIT / .FALSE. /
*
      DATA VPXPH1(3), VPXPH2(3), VPXPH3(3) / 1.475, 0.10, 0.55 /
      DATA VPXEHP(3), VPXEHC(3) / 0.025, 1.00 /
      DATA VPXEAW(3) / 0.05 /
      DATA IROTAR / 76, 77, 78, 79,  0, 80 /
*
      IF (.NOT. INIT) THEN
         INIT = .TRUE.
      END IF
*
*-- Initialize geometrical parameters in /XECGEO/
*
      CALL XEGINI
*
*-- Set up materials
*
      CALL GMMATE
*
*-- Set up tracking media
*
      CALL GMTMED
*
*--
*-- Define GEANT volumes
*--
*
*   The z=0 is located just in front of the window of the PMTs
*   on the front-side.
*
      VPLP(1) = PMTINT*FLOAT(NXPMT)
      VPLP(2) = PMTINT*FLOAT(NYPMT)
      VPLP(3) = PMTINT*FLOAT(NZPMT)*1.5
      CALL GSVOLU('LP  ', 'BOX ', TMMEG, VPLP, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for LP  :'', I8)') IVOL
         CALL REPORT('LPGEOM', 11, 'ERROR')
      END IF
      CALL GSATT('LP  ', 'SEEN', 0)
*
*-- Define the geometry of a PMT
*
      CALL XEGPMT
*
*-- Define the geometry of PMT holder plates
*
      CALL GSVOLU('XPH1', 'BOX ', TMXPH1, VPXPH1, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH1:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
      CALL GSVOLU('XPH2', 'BOX ', TMXPH2, VPXPH2, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH2:'', I8)') IVOL
         CALL REPORT('LPGEOM', 13, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
      CALL GSVOLU('XPH3', 'BOX ', TMXPH3, VPXPH3, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH3:'', I8)') IVOL
         CALL REPORT('LPGEOM', 14, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
*-- We can now fix the size of the liquid Xe volume
*-- and the vacuum volume
*
      ZMXELQ = -2.*VPXPWD(3) - VPXPMT(3)
     +        + ZPXPSS - VPXPSS(3) - 2.*VPXPHL(3,2) - 2.*VPXPHL(3,3)
      VPXELQ(1) = (PMTINT*FLOAT(NXPMT)/2. + ABS(ZMXELQ))
      VPXELQ(2) = PMTINT*FLOAT(NYPMT)/2.*FILL + ABS(ZMXELQ)/2
      VPXELQ(3) = (PMTINT*FLOAT(NZPMT)/2. + ABS(ZMXELQ))

      ZCXELQ = ZMXELQ + VPXELQ(3)
      CALL GSVOLU('XELQ', 'BOX ', TMXELQ, VPXELQ, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XELQ:'', I8)') IVOL
         CALL REPORT('LPGEOM', 15, 'ERROR')
      END IF
      CALL GSATT('XELQ', 'SEEN', 1)
*
      ZMXEVA = ZMXELQ - 4.*VPXEHP(3) - 2.*VPXEHC(3) - 5.0
      VPXEVA(1) = PMTINT*FLOAT(NXPMT)/2. + ABS(ZMXEVA)
      VPXEVA(2) = PMTINT*FLOAT(NYPMT)/2. + ABS(ZMXEVA)
      VPXEVA(3) = PMTINT*FLOAT(NZPMT)/2. + ABS(ZMXEVA)
      ZCXEVA = ZMXEVA + VPXEVA(3)
      CALL GSVOLU('XEVA', 'BOX ', TMXEVA, VPXEVA, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEVA:'', I8)') IVOL
         CALL REPORT('LPGEOM', 16, 'ERROR')
      END IF
      CALL GSATT('XEVA', 'SEEN', 0)
*
      CALL GSPOS('XEVA', 1, 'LP  ',
     +           0., 0., ZCXEVA, 0, 'ONLY')
*      CALL GSPOS('XELQ', 1, 'XEVA',
*     +           0., 0., 
*     +           -VPXEVA(3) + (ZMXELQ - ZMXEVA) + VPXELQ(3),
*     +           0, 'ONLY')
      CALL GSPOS('XELQ', 1, 'XEVA',0.,
     +           -PMTINT*FLOAT(NYPMT)/2.*(1-FILL)-ABS(ZMXELQ)/2,
     +           -VPXEVA(3) + (ZMXELQ - ZMXEVA) + VPXELQ(3),
     +           0, 'ONLY')
*
*-- Honeycomb window and Al window
*
      VPXEHP(1) = PMTINT*FLOAT(NXPMT)/2.
      VPXEHP(2) = PMTINT*FLOAT(NYPMT)/2.
      CALL GSVOLU('XEHP', 'BOX ', TMXEHP, VPXEHP, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEHP:'', I8)') IVOL
         CALL REPORT('LPGEOM', 17, 'ERROR')
      END IF
      CALL GSATT('XEHP', 'SEEN', 1)
      ZPXEHP(2) = ZMXELQ - VPXEHP(3)
      CALL GSPOS('XEHP', 2, 'XEVA',
     +           0., 0., -ZCXEVA + ZPXEHP(2), 0, 'ONLY')
*
      VPXEHC(1) = PMTINT*FLOAT(NXPMT)/2.
      VPXEHC(2) = PMTINT*FLOAT(NYPMT)/2.
      CALL GSVOLU('XEHC', 'BOX ', TMXEHC, VPXEHC, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEHC:'', I8)') IVOL
         CALL REPORT('LPGEOM', 18, 'ERROR')
      END IF
      CALL GSATT('XEHC', 'SEEN', 1)
      ZPXEHC = ZPXEHP(2) - VPXEHP(3) - VPXEHC(3)
      CALL GSPOS('XEHC', 1, 'XEVA',
     +           0., 0., -ZCXEVA + ZPXEHC, 0, 'ONLY')
*
      ZPXEHP(1) = ZPXEHC - VPXEHC(3) - VPXEHP(3)
      CALL GSPOS('XEHP', 1, 'XEVA',
     +           0., 0., -ZCXEVA + ZPXEHP(1), 0, 'ONLY')
*
      VPXEAW(1) = PMTINT*FLOAT(NXPMT)/2.
      VPXEAW(2) = PMTINT*FLOAT(NYPMT)/2.
      CALL GSVOLU('XEAW', 'BOX ', TMXEAW, VPXEAW, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEAW:'', I8)') IVOL
         CALL REPORT('LPGEOM', 19, 'ERROR')
      END IF
      CALL GSATT('XEAW', 'SEEN', 1)
      ZPXEAW = ZPXEHP(1) - VPXEHP(3) - 5.0 - VPXEAW(3)
      CALL GSPOS('XEAW', 1, 'LP  ',
     +           0., 0., ZCXEVA - VPXEVA(3) + (ZPXEAW - ZMXEVA),
     +           0, 'ONLY')
*
*-- Place PMTs and their holders
*
      CALL GSROTM(76,  90.,  90.,   0.,   0.,  90.,   0.)
      CALL GSROTM(77,  90.,  90., 180.,   0.,  90., 180.)
      CALL GSROTM(78,   0.,   0.,  90.,   0.,  90.,  90.)
      CALL GSROTM(79,   0.,   0.,  90., 180.,  90., 270.)
      CALL GSROTM(80,  90., 180.,  90.,  90., 180.,   0.)
*
      DO 100 IW = 1, NWALL
      IF (IW .EQ. 1 .OR. IW .EQ. 2) THEN
         XPOSWD = -PMTINT*FLOAT(NXPMT)/2. - VPXPWD(3)
         XPOSPM = XPOSWD - VPXPWD(3) - VPXPMT(3)
         XPOSHL(1) = XPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         XPOSHL(2) = XPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         XPOSHL(3) = XPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 2) THEN
            XPOSWD = -XPOSWD
            XPOSPM = -XPOSPM
            DO 10 I = 1, 3
 10         XPOSHL(I) = -XPOSHL(I)
         END IF
         YPOS0 = -PMTINT*FLOAT(NYPMT+1)/2.
         ZPOS0 = -PMTINT/2.
         DO 20 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NYPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NZPMT)/2.
            YPOSHL(I) = 0.
            ZPOSHL(I) = PMTINT*FLOAT(NZPMT)/2.
 20      CONTINUE
      ELSE IF (IW .EQ. 3 .OR. IW .EQ. 4) THEN
         YPOSWD = -PMTINT*FLOAT(NYPMT)/2. - VPXPWD(3)
         YPOSPM = YPOSWD - VPXPWD(3) - VPXPMT(3)
         YPOSHL(1) = YPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         YPOSHL(2) = YPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         YPOSHL(3) = YPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 4) THEN
            YPOSWD = -YPOSWD
            YPOSPM = -YPOSPM
            DO 30 I = 1, 3
 30         YPOSHL(I) = -YPOSHL(I)
         END IF
         ZPOS0 = -PMTINT/2.
         XPOS0 = -PMTINT*FLOAT(NXPMT+1)/2.
         DO 40 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NZPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NXPMT)/2.
            ZPOSHL(I) = PMTINT*FLOAT(NZPMT)/2.
            XPOSHL(I) = 0.
 40      CONTINUE
      ELSE IF (IW .EQ. 5 .OR. IW .EQ. 6) THEN
         ZPOSWD = -VPXPWD(3)
         ZPOSPM = ZPOSWD - VPXPWD(3) - VPXPMT(3)
         ZPOSHL(1) = ZPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         ZPOSHL(2) = ZPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         ZPOSHL(3) = ZPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 6) THEN
            ZPOSWD = -ZPOSWD + PMTINT*FLOAT(NZPMT)
            ZPOSPM = -ZPOSPM + PMTINT*FLOAT(NZPMT)
            DO 50 I = 1, 3
 50         ZPOSHL(I) = -ZPOSHL(I) + PMTINT*FLOAT(NZPMT)
         END IF
         XPOS0 = -PMTINT*FLOAT(NXPMT+1)/2.
         YPOS0 = -PMTINT*FLOAT(NYPMT+1)/2.
         DO 60 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NXPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NYPMT)/2.
            XPOSHL(I) = 0.
            YPOSHL(I) = 0.
 60      CONTINUE
      END IF
*
      IROT = IROTAR(IW)
*      CALL GSPOSP('XPH1', IW, 'XELQ',
      CALL GSPOSP('XPH1', IW, 'XEVA',
     +            XPOSHL(1), YPOSHL(1), -ZCXELQ+ZPOSHL(1), IROT, 'MANY',
     +            VPXPHL(1,1), 3)
*      CALL GSPOSP('XPH2', IW, 'XELQ',
      CALL GSPOSP('XPH2', IW, 'XEVA',
     +            XPOSHL(2), YPOSHL(2), -ZCXELQ+ZPOSHL(2), IROT, 'MANY',
     +            VPXPHL(1,2), 3)
*      CALL GSPOSP('XPH3', IW, 'XELQ',
      CALL GSPOSP('XPH3', IW, 'XEVA',
     +            XPOSHL(3), YPOSHL(3), -ZCXELQ+ZPOSHL(3), IROT, 'MANY',
     +            VPXPHL(1,3), 3)
*
      DO 90 IX = 1, NIJPMT(1,IW)
      DO 80 IY = 1, NIJPMT(2,IW)
         IF (IW .EQ. 1 .OR. IW .EQ. 2) THEN
            YPOSWD = YPOS0 + FLOAT(IX)*PMTINT
            ZPOSWD = ZPOS0 + FLOAT(IY)*PMTINT
            YPOSPM = YPOSWD
            ZPOSPM = ZPOSWD
         ELSE IF (IW .EQ. 3 .OR. IW .EQ. 4) THEN
            ZPOSWD = ZPOS0 + FLOAT(IX)*PMTINT
            XPOSWD = XPOS0 + FLOAT(IY)*PMTINT
            ZPOSPM = ZPOSWD
            XPOSPM = XPOSWD
         ELSE IF (IW .EQ. 5 .OR. IW .EQ. 6) THEN
            XPOSWD = XPOS0 + FLOAT(IX)*PMTINT
            YPOSWD = YPOS0 + FLOAT(IY)*PMTINT
            XPOSPM = XPOSWD
            YPOSPM = YPOSWD
         END IF
         IPMT = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
*         CALL GSPOS('XPWD', IPMT, 'XELQ',
         CALL GSPOS('XPWD', IPMT, 'XEVA',
     +              XPOSWD, YPOSWD, -ZCXELQ+ZPOSWD, IROT, 'ONLY')
*         CALL GSPOS('XPMT', IPMT, 'XELQ',
         CALL GSPOS('XPMT', IPMT, 'XEVA',
     +              XPOSPM, YPOSPM, -ZCXELQ+ZPOSPM, IROT, 'ONLY')
 80   CONTINUE
 90   CONTINUE
 100  CONTINUE
*
*-- Call user geometry routine
*
      CALL USGEOM
*
*-- Close geometry banks
*
      CALL GGCLOS
*
*-- Display the geometry
*
*     16-Feb-00  T. Mashimo  The following call to GDTREE has been
*     disabled, since it somehow causes core dump (in ixgetpl_)
*     on a Linux platform.
**    CALL GDTREE('LP  ', 0, 0)
      CALL ICLRWK(0, 0)
*
**    CALL GDSPEC('ECAL')
**    CALL ICLRWK(0, 0)
*
**    CALL GDRAWC('LP  ', 3, 0., 10., 10., 1.0, 1.0)
**    CALL ICLRWK(0, 0)
*
  999 CONTINUE
      RETURN
      END
